import * as secretsmanager from 'aws-cdk-lib/aws-secretsmanager';
import * as constructs from 'constructs';
import * as node from './node';
/**
 * @stability stable
 */
export declare enum FrameworkVersion {
    /**
     * @stability stable
     */
    VERSION_1_2 = "1.2",
    /**
     * @stability stable
     */
    VERSION_1_4 = "1.4"
}
/**
 * @stability stable
 */
export declare enum NetworkEdition {
    /**
     * @stability stable
     */
    STARTER = "STARTER",
    /**
     * @stability stable
     */
    STANDARD = "STANDARD"
}
/**
 * @stability stable
 */
export declare enum ThresholdComparator {
    /**
     * @stability stable
     */
    GREATER_THAN = "GREATER_THAN",
    /**
     * @stability stable
     */
    GREATER_THAN_OR_EQUAL_TO = "GREATER_THAN_OR_EQUAL_TO"
}
/**
 * Construct properties for `HyperledgerFabricNetwork`.
 *
 * @stability stable
 */
export interface HyperledgerFabricNetworkProps {
    /**
     * Managed Blockchain network name.
     *
     * @stability stable
     */
    readonly networkName: string;
    /**
     * Managed Blockchain network description.
     *
     * @default - Set to match network name
     * @stability stable
     */
    readonly networkDescription?: string;
    /**
     * Managed Blockchain member name.
     *
     * @stability stable
     */
    readonly memberName: string;
    /**
     * Managed Blockchain member description.
     *
     * @default - Set to match member name
     * @stability stable
     */
    readonly memberDescription?: string;
    /**
     * Hyperledger Fabric framework version.
     *
     * @default - FrameworkVersion.VERSION_1_4
     * @stability stable
     */
    readonly frameworkVersion?: FrameworkVersion;
    /**
     * Managed Blockchain network edition.
     *
     * @default - NetworkEdition.STANDARD
     * @stability stable
     */
    readonly networkEdition?: NetworkEdition;
    /**
     * The duration from the time that a proposal is created until it expires.
     *
     * @default - 24 hours
     * @stability stable
     */
    readonly proposalDurationInHours?: number;
    /**
     * The percentage of votes among all members that must be yes for a proposal to be approved.
     *
     * @default - 50 percent
     * @stability stable
     */
    readonly thresholdPercentage?: number;
    /**
     * Determines whether the yes votes must be greater than the threshold percentage or must be greater than or equal to the threhold percentage to be approved.
     *
     * @default - GREATER_THAN
     * @stability stable
     */
    readonly thresholdComparator?: ThresholdComparator;
    /**
     * List of nodes to create on the network.
     *
     * @default - One node with default configuration
     * @stability stable
     */
    readonly nodes?: Array<node.HyperledgerFabricNodeProps>;
}
/**
 * Creates a Hyperledger Fabric network on Amazon Managed Blockchain.
 *
 * @stability stable
 */
export declare class HyperledgerFabricNetwork extends constructs.Construct {
    /**
     * Managed Blockchain network name.
     *
     * @stability stable
     */
    readonly networkName: string;
    /**
     * Managed Blockchain network description.
     *
     * @stability stable
     */
    readonly networkDescription: string;
    /**
     * Managed Blockchain network identifier generated on construction.
     *
     * @stability stable
     */
    readonly networkId: string;
    /**
     * Managed Blockchain member name.
     *
     * @stability stable
     */
    readonly memberName: string;
    /**
     * Managed Blockchain member description.
     *
     * @stability stable
     */
    readonly memberDescription: string;
    /**
     * Managed Blockchain member identifier generated on construction.
     *
     * @stability stable
     */
    readonly memberId: string;
    /**
     * Hyperledger Fabric framework version.
     *
     * @stability stable
     */
    readonly frameworkVersion: FrameworkVersion;
    /**
     * Managed Blockchain network edition.
     *
     * @stability stable
     */
    readonly networkEdition: NetworkEdition;
    /**
     * The duration from the time that a proposal is created until it expires.
     *
     * @stability stable
     */
    readonly proposalDurationInHours: number;
    /**
     * The percentage of votes among all members that must be yes for a proposal to be approved.
     *
     * @stability stable
     */
    readonly thresholdPercentage: number;
    /**
     * Determines whether the yes votes must be greater than the threshold percentage or must be greater than or equal to the threhold percentage to be approved.
     *
     * @stability stable
     */
    readonly thresholdComparator: ThresholdComparator;
    /**
     * Managed Blockchain network VPC endpoint service name.
     *
     * @stability stable
     */
    readonly vpcEndpointServiceName: string;
    /**
     * Managed Blockchain network ordering service endpoint.
     *
     * @stability stable
     */
    readonly ordererEndpoint: string;
    /**
     * Managed Blockchain member CA endpoint.
     *
     * @stability stable
     */
    readonly caEndpoint: string;
    /**
     * Secret ARN for the Hyperledger Fabric admin password.
     *
     * @stability stable
     */
    readonly adminPasswordSecret: secretsmanager.Secret;
    /**
     * Secret for Hyperledger Fabric admin private key.
     *
     * @stability stable
     */
    readonly adminPrivateKeySecret: secretsmanager.Secret;
    /**
     * Secret for Hyperledger Fabric admin signed certificate.
     *
     * @stability stable
     */
    readonly adminSignedCertSecret: secretsmanager.Secret;
    /**
     * List of nodes created in the network.
     *
     * @stability stable
     */
    readonly nodes: Array<node.HyperledgerFabricNode>;
    /**
     * @stability stable
     */
    constructor(scope: constructs.Construct, id: string, props: HyperledgerFabricNetworkProps);
}
