import * as customresources from 'aws-cdk-lib/custom-resources';
import * as constructs from 'constructs';
import * as network from './network';
/**
 * Supported instance types for Managed Blockchain nodes.
 *
 * @stability stable
 */
export declare enum InstanceType {
    /**
     * @stability stable
     */
    BURSTABLE3_SMALL = "bc.t3.small",
    /**
     * @stability stable
     */
    BURSTABLE3_MEDIUM = "bc.t3.medium",
    /**
     * @stability stable
     */
    BURSTABLE3_LARGE = "bc.t3.large",
    /**
     * @stability stable
     */
    BURSTABLE3_XLARGE = "bc.t3.xlarge",
    /**
     * @stability stable
     */
    STANDARD5_LARGE = "bc.m5.large",
    /**
     * @stability stable
     */
    STANDARD5_XLARGE = "bc.m5.xlarge",
    /**
     * @stability stable
     */
    STANDARD5_XLARGE2 = "bc.m5.2xlarge",
    /**
     * @stability stable
     */
    STANDARD5_XLARGE4 = "bc.m5.4xlarge",
    /**
     * @stability stable
     */
    COMPUTE5_LARGE = "bc.c5.large",
    /**
     * @stability stable
     */
    COMPUTE5_XLARGE = "bc.c5.xlarge",
    /**
     * @stability stable
     */
    COMPUTE5_XLARGE2 = "bc.c5.2xlarge",
    /**
     * @stability stable
     */
    COMPUTE5_XLARGE4 = "bc.c5.4xlarge"
}
/**
 * Valid instance types for starter networks
 */
export declare const STARTER_INSTANCE_TYPES: InstanceType[];
/**
 * Construct properties for `HyperledgerFabricNode`.
 *
 * @stability stable
 */
export interface HyperledgerFabricNodeProps {
    /**
     * The Availability Zone in which the node will be created.
     *
     * @default - The first AZ in the region
     * @stability stable
     */
    readonly availabilityZone?: string;
    /**
     * The Amazon Managed Blockchain instance type for the node.
     *
     * @default - BURSTABLE3_SMALL
     * @stability stable
     */
    readonly instanceType?: InstanceType;
}
/**
 * Creates a Hyperledger Fabric node on an Amazon Managed Blockchain network.
 *
 * @stability stable
 */
export declare class HyperledgerFabricNode extends constructs.Construct {
    /**
     * @stability stable
     */
    static constructNodes(scope: network.HyperledgerFabricNetwork, nodeProps?: Array<HyperledgerFabricNodeProps>): HyperledgerFabricNode[];
    /**
     * Managed Blockchain network identifier.
     *
     * @stability stable
     */
    readonly networkId: string;
    /**
     * Managed Blockchain member identifier.
     *
     * @stability stable
     */
    readonly memberId: string;
    /**
     * Managed Blockchain node identifier generated on construction.
     *
     * @stability stable
     */
    readonly nodeId: string;
    /**
     * The Availability Zone in which the node exists.
     *
     * @stability stable
     */
    readonly availabilityZone: string;
    /**
     * The Amazon Managed Blockchain instance type for the node.
     *
     * @stability stable
     */
    readonly instanceType: InstanceType;
    /**
     * @stability stable
     */
    endpoint: string;
    /**
     * @stability stable
     */
    eventEndpoint: string;
    /**
     * @stability stable
     */
    constructor(scope: network.HyperledgerFabricNetwork, id: string, props?: HyperledgerFabricNodeProps);
    /**
     * @stability stable
     */
    fetchData(dataSdkCallPolicy: customresources.AwsCustomResourcePolicy): void;
}
